@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 2004, 2006 Free Software Foundation
+ *      Copyright (C) 2004, 2006, 2007 Free Software Foundation
  *      Copyright (C) 2000,2001 Fabio Fiorina
  *
  * This file is part of LIBTASN1.
@@ -59,7 +59,7 @@ _asn1_add_node (unsigned int type)
   list_type *listElement;
   node_asn *punt;
 
-  punt = (node_asn *) _asn1_malloc (sizeof (node_asn));
+  punt = (node_asn *) _asn1_calloc (1, sizeof (node_asn));
   if (punt == NULL)
     return NULL;
 
@@ -74,12 +74,7 @@ _asn1_add_node (unsigned int type)
   listElement->next = firstElement;
   firstElement = listElement;
 
-  punt->left = NULL;
-  punt->name = NULL;
   punt->type = type;
-  punt->value = NULL;
-  punt->down = NULL;
-  punt->right = NULL;
 
   return punt;
 }
@@ -1017,8 +1012,13 @@ parse_version_string (const char *s, int *major, int *minor, int *micro)
     return NULL;
   s++;
   s = parse_version_number (s, minor);
-  if (!s || *s != '.')
+  if (!s)
     return NULL;
+  if (*s != '.')
+    {
+      *micro = 0;
+      return s;
+    }
   s++;
   s = parse_version_number (s, micro);
   if (!s)
